import type { Metadata, Viewport } from 'next';
import { Inter } from 'next/font/google';
import PlausibleProvider from 'next-plausible';
import './globals.css';
import { cn } from '@/lib/utils';
import { Providers } from './providers';

const inter = Inter({ subsets: ['latin'], variable: '--font-sans' });

export const viewport: Viewport = {
  colorScheme: 'dark',
  themeColor: [
    //{ media: "(prefers-color-scheme: light)", color: "#f5f5f5" },
    //{ media: "(prefers-color-scheme: dark)", color: "#171717" },
    { color: '#052e16' },
  ],
};
export const metadata: Metadata = {
  title: 'Track Every Day!',
  description: 'A web app for tracking habits, activities and vices.',
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en" className="scroll-smooth">
      <head>
        <PlausibleProvider
          domain="trackevery.day"
          customDomain="https://analytics.schulze.network"
          selfHosted={true}
          enabled={true}
          trackOutboundLinks={true}
        />
      </head>
      <body className={cn('bg-background min-h-screen font-sans antialiased', inter.variable)}>
        <Providers>{children}</Providers>
      </body>
    </html>
  );
}
